@@ -1,6 +1,6 @@
 package main
 
-import "github.com/goplus/llgo/c"
+import "github.com/goplus/lib/c"
 
 func main() {
 	c.Printf(c.Str("Hello, world!\n"))
