@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2021 The GoPlus Authors (goplus.org). All rights reserved.
+ * Copyright (c) 2021 The XGo Authors (xgo.dev). All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,156 +17,55 @@
 package cl_test
 
 import (
-	"bytes"
-	"os"
 	"testing"
 
-	"github.com/goplus/gop/cl"
-	"github.com/goplus/gop/parser"
-	"github.com/goplus/gop/parser/fsx/memfs"
-	"github.com/goplus/gop/scanner"
-	"github.com/goplus/mod/modfile"
+	"github.com/goplus/xgo/cl"
+	"github.com/goplus/xgo/cl/cltest"
+	"github.com/goplus/xgo/parser/fsx/memfs"
 )
 
-func lookupClass(ext string) (c *modfile.Project, ok bool) {
-	switch ext {
-	case ".tgmx", ".tspx":
-		return &modfile.Project{
-			Ext: ".tgmx", Class: "*MyGame",
-			Works:    []*modfile.Class{{Ext: ".tspx", Class: "Sprite"}},
-			PkgPaths: []string{"github.com/goplus/gop/cl/internal/spx", "math"}}, true
-	case ".t2gmx", ".t2spx", ".t2spx2":
-		return &modfile.Project{
-			Ext: ".t2gmx", Class: "Game",
-			Works: []*modfile.Class{{Ext: ".t2spx", Class: "Sprite"},
-				{Ext: ".t2spx2", Class: "Sprite2"}},
-			PkgPaths: []string{"github.com/goplus/gop/cl/internal/spx2"}}, true
-	case "_t3spx.gox", ".t3spx2":
-		return &modfile.Project{
-			Works: []*modfile.Class{{Ext: "_t3spx.gox", Class: "Sprite"},
-				{Ext: ".t3spx2", Class: "Sprite2"}},
-			PkgPaths: []string{"github.com/goplus/gop/cl/internal/spx2"}}, true
-	case "_spx.gox":
-		return &modfile.Project{
-			Ext: "_spx.gox", Class: "Game",
-			Works:    []*modfile.Class{{Ext: "_spx.gox", Class: "Sprite"}},
-			PkgPaths: []string{"github.com/goplus/gop/cl/internal/spx3", "math"},
-			Import:   []*modfile.Import{{Path: "github.com/goplus/gop/cl/internal/spx3/jwt"}}}, true
-	case "_xtest.gox":
-		return &modfile.Project{
-			Ext: "_xtest.gox", Class: "App",
-			Works:    []*modfile.Class{{Ext: "_xtest.gox", Class: "Case"}},
-			PkgPaths: []string{"github.com/goplus/gop/test", "testing"}}, true
-	}
-	return
-}
-
-func spxParserConf() parser.Config {
-	return parser.Config{
-		ClassKind: func(fname string) (isProj bool, ok bool) {
-			ext := modfile.ClassExt(fname)
-			c, ok := lookupClass(ext)
-			if ok {
-				isProj = c.IsProj(ext, fname)
-			}
-			return
-		},
-	}
-}
-
 func gopSpxTest(t *testing.T, gmx, spxcode, expected string) {
-	gopSpxTestEx(t, gmx, spxcode, expected, "index.tgmx", "bar.tspx")
+	cltest.SpxEx(t, gmx, spxcode, expected, "index.tgmx", "bar.tspx")
 }
 
 func gopSpxTestEx(t *testing.T, gmx, spxcode, expected, gmxfile, spxfile string) {
-	gopSpxTestExConf(t, "gopSpxTest", gblConf, gmx, spxcode, expected, gmxfile, spxfile, "")
+	cltest.SpxWithConf(t, "gopSpxTest", cltest.Conf, gmx, spxcode, expected, gmxfile, spxfile, "")
 }
 
 func gopSpxTestEx2(t *testing.T, gmx, spxcode, expected, gmxfile, spxfile, resultFile string) {
-	gopSpxTestExConf(t, "gopSpxTest", gblConf, gmx, spxcode, expected, gmxfile, spxfile, resultFile)
+	cltest.SpxWithConf(t, "gopSpxTest", cltest.Conf, gmx, spxcode, expected, gmxfile, spxfile, resultFile)
 }
 
 func gopSpxTestExConf(t *testing.T, name string, conf *cl.Config, gmx, spxcode, expected, gmxfile, spxfile, resultFile string) {
-	t.Run(name, func(t *testing.T) {
-		cl.SetDisableRecover(true)
-		defer cl.SetDisableRecover(false)
-
-		fs := memfs.TwoFiles("/foo", spxfile, spxcode, gmxfile, gmx)
-		if gmxfile == "" {
-			fs = memfs.SingleFile("/foo", spxfile, spxcode)
-		}
-		pkgs, err := parser.ParseFSDir(gblFset, fs, "/foo", spxParserConf())
-		if err != nil {
-			scanner.PrintError(os.Stderr, err)
-			t.Fatal("ParseFSDir:", err)
-		}
-		bar := pkgs["main"]
-		pkg, err := cl.NewPackage("", bar, conf)
-		if err != nil {
-			t.Fatal("NewPackage:", err)
-		}
-		var b bytes.Buffer
-		err = pkg.WriteTo(&b, resultFile)
-		if err != nil {
-			t.Fatal("gogen.WriteTo failed:", err)
-		}
-		result := b.String()
-		if result != expected {
-			t.Fatalf("\nResult:\n%s\nExpected:\n%s\n", result, expected)
-		}
-	})
+	cltest.SpxWithConf(t, name, conf, gmx, spxcode, expected, gmxfile, spxfile, resultFile)
 }
 
 func gopSpxErrorTestEx(t *testing.T, msg, gmx, spxcode, gmxfile, spxfile string) {
-	fs := memfs.TwoFiles("/foo", spxfile, spxcode, gmxfile, gmx)
-	pkgs, err := parser.ParseFSDir(gblFset, fs, "/foo", spxParserConf())
-	if err != nil {
-		scanner.PrintError(os.Stderr, err)
-		t.Fatal("ParseFSDir:", err)
-	}
-	conf := *gblConf
-	conf.RelativeBase = "/foo"
-	conf.Recorder = nil
-	conf.NoFileLine = false
-	bar := pkgs["main"]
-	_, err = cl.NewPackage("", bar, &conf)
-	if err == nil {
-		t.Fatal("no error?")
-	}
-	if ret := err.Error(); ret != msg {
-		t.Fatalf("\nError: \"%s\"\nExpected: \"%s\"\n", ret, msg)
-	}
+	cltest.SpxErrorEx(t, msg, gmx, spxcode, gmxfile, spxfile)
 }
 
-func TestSpxNoGame(t *testing.T) {
-	gopSpxTestEx(t, ``, `
-`, `package main
-
-import "github.com/goplus/gop/cl/internal/spx"
-
-type Kai struct {
-	spx.Sprite
-	*MyGame
-}
-type MyGame struct {
-	*spx.MyGame
-}
-
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
-func (this *Kai) Main() {
-}
-func (this *MyGame) Main() {
-	spx.Gopt_MyGame_Main(this)
-}
-func main() {
-	new(MyGame).Main()
-}
-`, "", "Kai.tspx")
+func gopSpxErrorTestMap(t *testing.T, msg string, dirs map[string][]string, files map[string]string) {
+	cltest.SpxErrorFS(t, msg, memfs.New(dirs, files))
 }
 
 func TestSpxError(t *testing.T) {
+	gopSpxErrorTestEx(t, `Game.tgmx:7:16: cannot use *Kai (type Kai) as type github.com/goplus/xgo/cl/internal/spx.Sprite in slice literal`, `
+var (
+	foo []Sprite
+	Kai *Kai
+)
+
+foo = []Sprite{*Kai}
+`, ``, "Game.tgmx", "Kai.tspx")
+
+	gopSpxErrorTestEx(t, `Game.tgmx:1:6: Game redeclared in this block
+	previous declaration at Game.tgmx:1:1
+Game.tgmx:1:1: invalid receiver type Game (Game is an interface type)
+Game.tgmx:1:1: invalid receiver type Game (Game is an interface type)`, `type Game interface {}`, ``, "Game.tgmx", "Kai.tspx")
+
+	gopSpxErrorTestEx(t, `Kai.tspx:1:1: Kai redeclared in this block
+	previous declaration at Game.tgmx:1:6`, `type Kai interface {}`, ``, "Game.tgmx", "Kai.tspx")
+
 	gopSpxErrorTestEx(t, `Game.tgmx:6:2: userScore redeclared
 	Game.tgmx:5:2 other declaration of userScore`, `
 import "bytes"
@@ -192,63 +91,53 @@ var (
 )
 println "hi"
 `, "Game.tgmx", "Kai.tspx")
+
+	gopSpxErrorTestEx(t, `Game.t4gmx:6:2: userScore redeclared
+	Game.t4gmx:5:2 other declaration of userScore
+Kai.t4spx:1:1: cannot use  (type *Kai) as type github.com/goplus/xgo/cl/internal/spx4.Sprite in argument to `, `
+import "bytes"
+var (
+	Kai Kai
+	userScore int
+	userScore string
+)
+`, `
+println "hi"
+`, "Game.t4gmx", "Kai.t4spx")
+
+	gopSpxErrorTestMap(t, `Kai.t4spx:4:2: userScore redeclared
+	Kai.t4spx:3:2 other declaration of userScore
+Greem.t4spx:1:1: cannot use  (type *Greem) as type github.com/goplus/xgo/cl/internal/spx4.Sprite in argument to `, map[string][]string{
+		"/foo": {"Game.t4gmx", "Kai.t4spx", "Greem.t4spx"},
+	}, map[string]string{
+		"/foo/Game.t4gmx": `println "hi"`,
+		"/foo/Kai.t4spx": `var (
+	Kai Kai
+	userScore int
+	userScore string
+)`,
+		"/foo/Greem.t4spx": ``,
+	})
+
+	gopSpxErrorTestMap(t, `Game.t4gmx:1:9: cannot use backdropName (type string) as type error in assignment`, map[string][]string{
+		"/foo": {"Game.t4gmx"},
+	}, map[string]string{
+		"/foo/Game.t4gmx": `println backdropName!`,
+	})
+
+	gopSpxErrorTestEx(t, `Game.t5gmx:4:2: Kai conflicts with class name.
+	rename the field to resolve the naming conflict.
+Kai.t5spx:1:1: cannot use  (type *Kai) as type github.com/goplus/xgo/cl/internal/spx4.Sprite in argument to `, `
+
+var (
+	Kai Kai
+)
+`, `
+println "hi"
+`, "Game.t5gmx", "Kai.t5spx")
 }
 
 func TestSpxBasic(t *testing.T) {
-	gopSpxTestEx(t, `
-func onInit() {
-	for {
-	}
-}
-
-initGameApp
-`, `
-func onMsg(msg string) {
-	for {
-		say "Hi"
-	}
-}
-`, `package main
-
-import "github.com/goplus/gop/cl/internal/spx"
-
-type Game struct {
-	*spx.MyGame
-}
-type Kai struct {
-	spx.Sprite
-	*Game
-}
-
-func (this *Game) onInit() {
-	for {
-		spx.SchedNow()
-	}
-}
-func (this *Game) MainEntry() {
-	this.InitGameApp()
-}
-func (this *Game) Main() {
-	spx.Gopt_MyGame_Main(this)
-}
-func (this *Kai) onMsg(msg string) {
-	for {
-		spx.Sched()
-		this.Say("Hi")
-	}
-}
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
-func (this *Kai) Main() {
-}
-func main() {
-	new(Game).Main()
-}
-`, "Game.tgmx", "Kai.tspx")
-}
-
-func TestSpxBasic2(t *testing.T) {
 	gopSpxTest(t, `
 import (
 	"fmt"
@@ -270,7 +159,7 @@ func onInit() {
 
 import (
 	"fmt"
-	"github.com/goplus/gop/cl/internal/spx"
+	"github.com/goplus/xgo/cl/internal/spx"
 )
 
 const Foo = 1
@@ -294,9 +183,6 @@ func (this *index) MainEntry() {
 func (this *index) Main() {
 	spx.Gopt_MyGame_Main(this)
 }
-func (this *bar) Classfname() string {
-	return "bar"
-}
 func (this *bar) Main() {
 }
 func main() {
@@ -305,16 +191,6 @@ func main() {
 `)
 }
 
-func _TestMatrix1(t *testing.T) {
-	gopSpxTest(t, `
-echo [
-	1, 2, 3
-	4, 5, 6
-]
-`, ``, `
-`)
-}
-
 func TestEnvOp(t *testing.T) {
 	gopSpxTest(t, `
 echo ${PATH}, $id
@@ -322,7 +198,7 @@ echo ${PATH}, $id
 
 import (
 	"fmt"
-	"github.com/goplus/gop/cl/internal/spx"
+	"github.com/goplus/xgo/cl/internal/spx"
 )
 
 type bar struct {
@@ -339,9 +215,6 @@ func (this *index) MainEntry() {
 func (this *index) Main() {
 	spx.Gopt_MyGame_Main(this)
 }
-func (this *bar) Classfname() string {
-	return "bar"
-}
 func (this *bar) Main() {
 }
 func main() {
@@ -350,14 +223,14 @@ func main() {
 `)
 }
 
-func TestSpxGopEnv(t *testing.T) {
+func TestSpxXGoEnv(t *testing.T) {
 	gopSpxTest(t, `
 echo "${PATH}"
 `, ``, `package main
 
 import (
 	"fmt"
-	"github.com/goplus/gop/cl/internal/spx"
+	"github.com/goplus/xgo/cl/internal/spx"
 	"strconv"
 )
 
@@ -375,9 +248,6 @@ func (this *index) MainEntry() {
 func (this *index) Main() {
 	spx.Gopt_MyGame_Main(this)
 }
-func (this *bar) Classfname() string {
-	return "bar"
-}
 func (this *bar) Main() {
 }
 func main() {
@@ -386,7 +256,7 @@ func main() {
 `)
 }
 
-func TestSpxGopExec(t *testing.T) {
+func TestSpxXGoExec(t *testing.T) {
 	gopSpxTest(t, `
 vim "a.txt"
 vim
@@ -395,7 +265,7 @@ capout => { ls }
 capout => { ls "-l" }
 `, ``, `package main
 
-import "github.com/goplus/gop/cl/internal/spx"
+import "github.com/goplus/xgo/cl/internal/spx"
 
 type bar struct {
 	spx.Sprite
@@ -419,9 +289,6 @@ func (this *index) MainEntry() {
 func (this *index) Main() {
 	spx.Gopt_MyGame_Main(this)
 }
-func (this *bar) Classfname() string {
-	return "bar"
-}
 func (this *bar) Main() {
 }
 func main() {
@@ -448,7 +315,7 @@ func onInit() {
 `, `package main
 
 import (
-	"github.com/goplus/gop/cl/internal/spx"
+	"github.com/goplus/xgo/cl/internal/spx"
 	"math"
 )
 
@@ -477,9 +344,6 @@ func (this *bar) onInit() {
 	this.Say("Where do you come from?", 2)
 	this.Broadcast__0("msg2")
 }
-func (this *bar) Classfname() string {
-	return "bar"
-}
 func (this *bar) Main() {
 }
 func main() {
@@ -512,7 +376,7 @@ func onCloned() {
 }
 `, `package main
 
-import "github.com/goplus/gop/cl/internal/spx"
+import "github.com/goplus/xgo/cl/internal/spx"
 
 type Game struct {
 	*spx.MyGame
@@ -539,9 +403,6 @@ func (this *Kai) onInit() {
 func (this *Kai) onCloned() {
 	this.Say("Hi")
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -566,7 +427,7 @@ println "Hi"
 
 import (
 	"fmt"
-	"github.com/goplus/gop/cl/internal/spx"
+	"github.com/goplus/xgo/cl/internal/spx"
 )
 
 type Kai struct {
@@ -590,102 +451,12 @@ func (this *index) Main() {
 func (this *Kai) Main() {
 	fmt.Println("Hi")
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func main() {
 	new(index).Main()
 }
 `, "index.tgmx", "Kai.tspx")
 }
 
-func TestSpxRunWithWorkers(t *testing.T) {
-	gopSpxTestEx(t, `
-var (
-	Kai Kai
-)
-
-run
-`, `
-echo jwt.token("Hi")
-`, `package main
-
-import (
-	"fmt"
-	"github.com/goplus/gop/cl/internal/spx3"
-	"github.com/goplus/gop/cl/internal/spx3/jwt"
-)
-
-type Kai struct {
-	spx3.Sprite
-	*Game
-}
-type Game struct {
-	spx3.Game
-	Kai Kai
-}
-
-func (this *Game) MainEntry() {
-	this.Run()
-}
-func (this *Game) Main() {
-	spx3.Gopt_Game_Main(this, new(Kai))
-}
-func (this *Kai) Main(_gop_arg0 string) {
-	this.Sprite.Main(_gop_arg0)
-	fmt.Println(jwt.Token("Hi"))
-}
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
-func main() {
-	new(Game).Main()
-}
-`, "main_spx.gox", "Kai_spx.gox")
-}
-
-func TestSpxNewObj(t *testing.T) {
-	gopSpxTestEx(t, `
-a := new
-a.run
-b := new(Sprite)
-echo b.name
-`, ``, `package main
-
-import (
-	"fmt"
-	"github.com/goplus/gop/cl/internal/spx3"
-)
-
-type Kai struct {
-	spx3.Sprite
-	*Game
-}
-type Game struct {
-	spx3.Game
-}
-
-func (this *Game) MainEntry() {
-	a := spx3.New()
-	a.Run()
-	b := new(spx3.Sprite)
-	fmt.Println(b.Name())
-}
-func (this *Game) Main() {
-	spx3.Gopt_Game_Main(this, new(Kai))
-}
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
-func (this *Kai) Main(_gop_arg0 string) {
-	this.Sprite.Main(_gop_arg0)
-}
-func main() {
-	new(Game).Main()
-}
-`, "main_spx.gox", "Kai_spx.gox")
-}
-
 func TestSpx2(t *testing.T) {
 	gopSpxTestEx(t, `
 println("Hi")
@@ -696,7 +467,7 @@ func onMsg(msg string) {
 
 import (
 	"fmt"
-	"github.com/goplus/gop/cl/internal/spx2"
+	"github.com/goplus/xgo/cl/internal/spx2"
 )
 
 type Game struct {
@@ -715,9 +486,6 @@ func (this *Game) Main() {
 }
 func (this *Kai) onMsg(msg string) {
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -726,84 +494,8 @@ func main() {
 `, "Game.t2gmx", "Kai.t2spx")
 }
 
-func TestSpx3(t *testing.T) {
-	gopSpxTestEx(t, `
-println("Hi, Sprite2")
-`, `
-func onMsg(msg string) {
-}
-`, `package main
-
-import (
-	"fmt"
-	"github.com/goplus/gop/cl/internal/spx2"
-)
-
-type Game struct {
-	spx2.Game
-}
-type Kai struct {
-	spx2.Sprite2
-	*Game
-}
-
-func (this *Game) MainEntry() {
-	fmt.Println("Hi, Sprite2")
-}
-func (this *Game) Main() {
-	(*spx2.Game).Main(&this.Game)
-}
-func (this *Kai) onMsg(msg string) {
-}
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
-func (this *Kai) Main() {
-}
-func main() {
-	new(Game).Main()
-}
-`, "Game.t2gmx", "Kai.t2spx2")
-}
-
-func TestSpx4(t *testing.T) {
-	gopSpxTestEx(t, `
-println("Hi, Sprite")
-`, `
-func onMsg(msg string) {
-}
-`, `package main
-
-import (
-	"fmt"
-	"github.com/goplus/gop/cl/internal/spx2"
-)
-
-type Dog struct {
-	spx2.Sprite
-}
-type Kai struct {
-	spx2.Sprite2
-}
-
-func (this *Dog) Main() {
-	fmt.Println("Hi, Sprite")
-}
-func (this *Dog) Classfname() string {
-	return "Dog"
-}
-func (this *Kai) onMsg(msg string) {
-}
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
-func (this *Kai) Main() {
-}
-`, "Dog_t3spx.gox", "Kai.t3spx2")
-}
-
 func TestSpxMainEntry(t *testing.T) {
-	conf := *gblConf
+	conf := *cltest.Conf
 	conf.Importer = nil
 	conf.NoAutoGenMain = false
 
@@ -811,7 +503,7 @@ func TestSpxMainEntry(t *testing.T) {
 `, `
 `, `package main
 
-import "github.com/goplus/gop/cl/internal/spx2"
+import "github.com/goplus/xgo/cl/internal/spx2"
 
 type Game struct {
 	spx2.Game
@@ -826,9 +518,6 @@ func (this *Game) MainEntry() {
 func (this *Game) Main() {
 	(*spx2.Game).Main(&this.Game)
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -842,7 +531,7 @@ var (
 `, `
 `, `package main
 
-import "github.com/goplus/gop/cl/internal/spx2"
+import "github.com/goplus/xgo/cl/internal/spx2"
 
 type Game struct {
 	spx2.Game
@@ -858,9 +547,6 @@ func (this *Game) MainEntry() {
 func (this *Game) Main() {
 	(*spx2.Game).Main(&this.Game)
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -885,7 +571,7 @@ func onMsg(msg string) {
 
 import (
 	"fmt"
-	"github.com/goplus/gop/cl/internal/spx2"
+	"github.com/goplus/xgo/cl/internal/spx2"
 )
 
 type Game struct {
@@ -908,9 +594,6 @@ func (this *Kai) Main() {
 }
 func (this *Kai) onMsg(msg string) {
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func main() {
 	new(Game).Main()
 }
@@ -931,7 +614,7 @@ func onMsg(msg string) {
 }
 `, `package main
 
-import "github.com/goplus/gop/cl/internal/spx"
+import "github.com/goplus/xgo/cl/internal/spx"
 
 type Game struct {
 	*spx.MyGame
@@ -957,9 +640,6 @@ func (this *Kai) onMsg(msg string) {
 		this.Say("Hi")
 	}
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -1000,7 +680,7 @@ func onCloned() {
 }
 `, `package main
 
-import "github.com/goplus/gop/cl/internal/spx"
+import "github.com/goplus/xgo/cl/internal/spx"
 
 type info struct {
 	x int
@@ -1034,9 +714,6 @@ func (this *Kai) onInit() {
 func (this *Kai) onCloned() {
 	this.Say("Hi")
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -1061,7 +738,7 @@ func onMsg(msg string) {
 }
 `, `package main
 
-import "github.com/goplus/gop/cl/internal/spx"
+import "github.com/goplus/xgo/cl/internal/spx"
 
 type Game struct {
 	*spx.MyGame
@@ -1079,9 +756,6 @@ func (this *Game) Main() {
 }
 func (this *Kai) onMsg(msg string) {
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -1101,7 +775,7 @@ func onMsg(msg string) {
 
 import (
 	"fmt"
-	"github.com/goplus/gop/cl/internal/spx"
+	"github.com/goplus/xgo/cl/internal/spx"
 )
 
 type Game struct {
@@ -1121,9 +795,6 @@ func (this *Game) Main() {
 func (this *Kai) onMsg(msg string) {
 	this.Position().Add__0(100, 200)
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -1156,7 +827,7 @@ func onMsg(msg string) {
 
 import (
 	"fmt"
-	"github.com/goplus/gop/cl/internal/spx"
+	"github.com/goplus/xgo/cl/internal/spx"
 )
 
 type Game struct {
@@ -1188,9 +859,6 @@ func (this *Kai) onMsg(msg string) {
 	fmt.Println(this.Vector().X)
 	fmt.Println(this.Vector().Self().Self())
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -1249,7 +917,7 @@ onKey2 "hello", key => {
 }
 `, `package main
 
-import "github.com/goplus/gop/cl/internal/spx"
+import "github.com/goplus/xgo/cl/internal/spx"
 
 type Mesh struct {
 }
@@ -1302,9 +970,6 @@ func (this *Kai) Main() {
 	spx.Gopt_Sprite_OnKey2(this, "hello", func(key string) {
 	})
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func main() {
 	new(Game).Main()
 }
@@ -1323,13 +988,12 @@ t.run "a test", t => {
 
 import (
 	"fmt"
-	"github.com/goplus/gop/test"
+	"github.com/goplus/xgo/test"
 	"testing"
 )
 
 type caseFoo struct {
 	test.Case
-	*App
 }
 type App struct {
 	test.App
@@ -1344,9 +1008,6 @@ func (this *caseFoo) Main() {
 		t.Fatal("failed")
 	})
 }
-func (this *caseFoo) Classfname() string {
-	return "Foo"
-}
 func TestFoo(t *testing.T) {
 	test.Gopt_Case_TestMain(new(caseFoo), t)
 }
@@ -1364,7 +1025,7 @@ t.log "Hi"
 `, `package main
 
 import (
-	"github.com/goplus/gop/test"
+	"github.com/goplus/xgo/test"
 	"testing"
 )
 
@@ -1375,16 +1036,13 @@ type case_foo struct {
 func (this *case_foo) Main() {
 	this.T().Log("Hi")
 }
-func (this *case_foo) Classfname() string {
-	return "foo"
-}
 func Test_foo(t *testing.T) {
 	test.Gopt_Case_TestMain(new(case_foo), t)
 }
 `, "main.gox", "foo_xtest.gox", "_test")
 }
 
-func TestGopxNoFunc(t *testing.T) {
+func TestGoxNoFunc(t *testing.T) {
 	gopClTestFile(t, `
 var (
 	a int
@@ -1397,7 +1055,43 @@ type foo struct {
 `, "foo.gox")
 }
 
-func TestClassFileGopx(t *testing.T) {
+func TestGoxOverload(t *testing.T) {
+	gopClTestFile(t, `
+func addString(a, b string) string {
+	return a + b
+}
+
+func addInt(a, b int) int {
+	return a + b
+}
+
+func add = (
+	addInt
+	func(a, b float64) float64 {
+		return a + b
+	}
+	addString
+)
+`, `package main
+
+const XGoo_Rect_add = ".addInt,,.addString"
+
+type Rect struct {
+}
+
+func (this *Rect) addString(a string, b string) string {
+	return a + b
+}
+func (this *Rect) addInt(a int, b int) int {
+	return a + b
+}
+func (this *Rect) add__1(a float64, b float64) float64 {
+	return a + b
+}
+`, "Rect.gox")
+}
+
+func TestClassFileGox(t *testing.T) {
 	gopClTestFile(t, `
 var (
 	BaseClass
@@ -1470,8 +1164,8 @@ func (this *Rect) test() {
 	gopClTestFile(t, `
 import "bytes"
 var (
-	*bytes.Buffer "spec:\"buffer\""
-	a int "json:\"a\""
+	*bytes.Buffer "buffer"
+	a int "a"
 	b int
 )
 func test(){}
@@ -1480,8 +1174,8 @@ func test(){}
 import "bytes"
 
 type Rect struct {
-	*bytes.Buffer `+"`spec:\"buffer\"`"+`
-	a             int `+"`json:\"a\"`"+`
+	*bytes.Buffer `+"`_:\"buffer\"`"+`
+	a             int `+"`_:\"a\"`"+`
 	b             int
 }
 
