@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2021 The GoPlus Authors (goplus.org). All rights reserved.
+ * Copyright (c) 2021 The XGo Authors (xgo.dev). All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,8 +22,8 @@ import (
 	"testing"
 
 	"github.com/goplus/gogen"
-	"github.com/goplus/gop/cl"
-	"github.com/goplus/gop/cl/cltest"
+	"github.com/goplus/xgo/cl"
+	"github.com/goplus/xgo/cl/cltest"
 )
 
 const (
@@ -33,10 +33,11 @@ const (
 var (
 	gblConfLine  *cl.Config
 	gotypesalias bool
+	go1point     int
 )
 
 func init() {
-	cltest.Gop.Root = gopRootDir
+	cltest.XGo.Root = gopRootDir
 	conf := cltest.Conf
 	gblConfLine = &cl.Config{
 		Fset:          conf.Fset,
@@ -47,6 +48,7 @@ func init() {
 		NoAutoGenMain: true,
 	}
 	gotypesalias = cltest.EnableTypesalias()
+	go1point = cltest.Go1Point()
 }
 
 func gopClNamedTest(t *testing.T, name string, gopcode, expected string) {
@@ -310,7 +312,7 @@ func init() {
 func TestSlogan(t *testing.T) {
 	gopClTest(t, `
 fields := ["engineering", "STEM education", "data science"]
-println "The Go+ Language for", fields.join(", ")
+println "The XGo Language for", fields.join(", ")
 `, `package main
 
 import (
@@ -320,7 +322,7 @@ import (
 
 func main() {
 	fields := []string{"engineering", "STEM education", "data science"}
-	fmt.Println("The Go+ Language for", strings.Join(fields, ", "))
+	fmt.Println("The XGo Language for", strings.Join(fields, ", "))
 }
 `)
 }
@@ -704,12 +706,12 @@ func t() (int, int, error) {
 	return 0, 0, nil
 }
 func main() {
-	a, b := func() (_gop_ret int, _gop_ret2 int) {
-		var _gop_err error
-		_gop_ret, _gop_ret2, _gop_err = t()
-		if _gop_err != nil {
-			_gop_err = errors.NewFrame(_gop_err, "t()", "/foo/bar.gop", 9, "main.main")
-			panic(_gop_err)
+	a, b := func() (_xgo_ret int, _xgo_ret2 int) {
+		var _xgo_err error
+		_xgo_ret, _xgo_ret2, _xgo_err = t()
+		if _xgo_err != nil {
+			_xgo_err = errors.NewFrame(_xgo_err, "t()", "/foo/bar.xgo", 9, "main.main")
+			panic(_xgo_err)
 		}
 		return
 	}()
@@ -737,11 +739,11 @@ func t() error {
 }
 func main() {
 	func() {
-		var _gop_err error
-		_gop_err = t()
-		if _gop_err != nil {
-			_gop_err = errors.NewFrame(_gop_err, "t()", "/foo/bar.gop", 9, "main.main")
-			panic(_gop_err)
+		var _xgo_err error
+		_xgo_err = t()
+		if _xgo_err != nil {
+			_xgo_err = errors.NewFrame(_xgo_err, "t()", "/foo/bar.xgo", 9, "main.main")
+			panic(_xgo_err)
 		}
 		return
 	}()
@@ -1221,7 +1223,7 @@ type BigInt struct {
 }
 
 func TestAutoProperty(t *testing.T) {
-	gopClTest(t, `import "github.com/goplus/gop/ast/goptest"
+	gopClTest(t, `import "github.com/goplus/xgo/ast/goptest"
 
 func foo(script string) {
 	doc := goptest.New(script)!
@@ -1233,18 +1235,18 @@ func foo(script string) {
 
 import (
 	"fmt"
-	"github.com/goplus/gop/ast/gopq"
-	"github.com/goplus/gop/ast/goptest"
+	"github.com/goplus/xgo/ast/gopq"
+	"github.com/goplus/xgo/ast/goptest"
 	"github.com/qiniu/x/errors"
 )
 
 func foo(script string) {
-	doc := func() (_gop_ret gopq.NodeSet) {
-		var _gop_err error
-		_gop_ret, _gop_err = goptest.New(script)
-		if _gop_err != nil {
-			_gop_err = errors.NewFrame(_gop_err, "goptest.New(script)", "/foo/bar.gop", 4, "main.foo")
-			panic(_gop_err)
+	doc := func() (_xgo_ret gopq.NodeSet) {
+		var _xgo_err error
+		_xgo_ret, _xgo_err = goptest.New(script)
+		if _xgo_err != nil {
+			_xgo_err = errors.NewFrame(_xgo_err, "goptest.New(script)", "/foo/bar.xgo", 4, "main.foo")
+			panic(_xgo_err)
 		}
 		return
 	}()
@@ -1267,18 +1269,18 @@ func foo(script string) {
 
 import (
 	"fmt"
-	"github.com/goplus/gop/ast/gopq"
-	"github.com/goplus/gop/ast/goptest"
+	"github.com/goplus/xgo/ast/gopq"
+	"github.com/goplus/xgo/ast/goptest"
 	"github.com/qiniu/x/errors"
 )
 
 func foo(script string) {
-	doc := func() (_gop_ret gopq.NodeSet) {
-		var _gop_err error
-		_gop_ret, _gop_err = goptest.New(script)
-		if _gop_err != nil {
-			_gop_err = errors.NewFrame(_gop_err, "goptest.New(script)", "/foo/bar.gop", 4, "main.foo")
-			panic(_gop_err)
+	doc := func() (_xgo_ret gopq.NodeSet) {
+		var _xgo_err error
+		_xgo_ret, _xgo_err = goptest.New(script)
+		if _xgo_err != nil {
+			_xgo_err = errors.NewFrame(_xgo_err, "goptest.New(script)", "/foo/bar.xgo", 4, "main.foo")
+			panic(_xgo_err)
 		}
 		return
 	}()
@@ -1305,22 +1307,22 @@ import (
 func add(x string, y string) (int, error) {
 	var _autoGo_1 int
 	{
-		var _gop_err error
-		_autoGo_1, _gop_err = strconv.Atoi(x)
-		if _gop_err != nil {
-			_gop_err = errors.NewFrame(_gop_err, "strconv.Atoi(x)", "/foo/bar.gop", 5, "main.add")
-			return 0, _gop_err
+		var _xgo_err error
+		_autoGo_1, _xgo_err = strconv.Atoi(x)
+		if _xgo_err != nil {
+			_xgo_err = errors.NewFrame(_xgo_err, "strconv.Atoi(x)", "/foo/bar.xgo", 5, "main.add")
+			return 0, _xgo_err
 		}
 		goto _autoGo_2
 	_autoGo_2:
 	}
 	var _autoGo_3 int
 	{
-		var _gop_err error
-		_autoGo_3, _gop_err = strconv.Atoi(y)
-		if _gop_err != nil {
-			_gop_err = errors.NewFrame(_gop_err, "strconv.Atoi(y)", "/foo/bar.gop", 5, "main.add")
-			return 0, _gop_err
+		var _xgo_err error
+		_autoGo_3, _xgo_err = strconv.Atoi(y)
+		if _xgo_err != nil {
+			_xgo_err = errors.NewFrame(_xgo_err, "strconv.Atoi(y)", "/foo/bar.xgo", 5, "main.add")
+			return 0, _xgo_err
 		}
 		goto _autoGo_4
 	_autoGo_4:
@@ -1342,17 +1344,17 @@ func addSafe(x, y string) int {
 import "strconv"
 
 func addSafe(x string, y string) int {
-	return func() (_gop_ret int) {
-		var _gop_err error
-		_gop_ret, _gop_err = strconv.Atoi(x)
-		if _gop_err != nil {
+	return func() (_xgo_ret int) {
+		var _xgo_err error
+		_xgo_ret, _xgo_err = strconv.Atoi(x)
+		if _xgo_err != nil {
 			return 0
 		}
 		return
-	}() + func() (_gop_ret int) {
-		var _gop_err error
-		_gop_ret, _gop_err = strconv.Atoi(y)
-		if _gop_err != nil {
+	}() + func() (_xgo_ret int) {
+		var _xgo_err error
+		_xgo_ret, _xgo_err = strconv.Atoi(y)
+		if _xgo_err != nil {
 			return 0
 		}
 		return
@@ -1371,12 +1373,12 @@ import (
 	"github.com/qiniu/x/errors"
 )
 
-var ret int = func() (_gop_ret int) {
-	var _gop_err error
-	_gop_ret, _gop_err = fmt.Println("Hi")
-	if _gop_err != nil {
-		_gop_err = errors.NewFrame(_gop_err, "println(\"Hi\")", "/foo/bar.gop", 2, "main.main")
-		panic(_gop_err)
+var ret int = func() (_xgo_ret int) {
+	var _xgo_err error
+	_xgo_ret, _xgo_err = fmt.Println("Hi")
+	if _xgo_err != nil {
+		_xgo_err = errors.NewFrame(_xgo_err, "println(\"Hi\")", "/foo/bar.xgo", 2, "main.main")
+		panic(_xgo_err)
 	}
 	return
 }()
@@ -1399,11 +1401,11 @@ func mkdir(name string) error {
 }
 func main() {
 	func() {
-		var _gop_err error
-		_gop_err = mkdir("foo")
-		if _gop_err != nil {
-			_gop_err = errors.NewFrame(_gop_err, "mkdir \"foo\"", "/foo/bar.gop", 6, "main.main")
-			panic(_gop_err)
+		var _xgo_err error
+		_xgo_err = mkdir("foo")
+		if _xgo_err != nil {
+			_xgo_err = errors.NewFrame(_xgo_err, "mkdir \"foo\"", "/foo/bar.xgo", 6, "main.main")
+			panic(_xgo_err)
 		}
 		return
 	}()
@@ -1426,12 +1428,12 @@ func foo() (func(), error) {
 	return nil, nil
 }
 func main() {
-	func() (_gop_ret func()) {
-		var _gop_err error
-		_gop_ret, _gop_err = foo()
-		if _gop_err != nil {
-			_gop_err = errors.NewFrame(_gop_err, "foo()", "/foo/bar.gop", 6, "main.main")
-			panic(_gop_err)
+	func() (_xgo_ret func()) {
+		var _xgo_err error
+		_xgo_ret, _xgo_err = foo()
+		if _xgo_err != nil {
+			_xgo_err = errors.NewFrame(_xgo_err, "foo()", "/foo/bar.xgo", 6, "main.main")
+			panic(_xgo_err)
 		}
 		return
 	}()()
@@ -1469,10 +1471,10 @@ var x, y uint128
 var z uint128 = x + y
 `, `package main
 
-import "github.com/goplus/gop/builtin/ng"
+import "github.com/qiniu/x/xgo/ng"
 
 var x, y ng.Uint128
-var z ng.Uint128 = (ng.Uint128).Gop_Add__1(x, y)
+var z ng.Uint128 = (ng.Uint128).XGo_Add__1(x, y)
 `)
 }
 
@@ -1482,10 +1484,10 @@ var x, y int128
 var z int128 = x + y
 `, `package main
 
-import "github.com/goplus/gop/builtin/ng"
+import "github.com/qiniu/x/xgo/ng"
 
 var x, y ng.Int128
-var z ng.Int128 = (ng.Int128).Gop_Add__1(x, y)
+var z ng.Int128 = (ng.Int128).XGo_Add__1(x, y)
 `)
 }
 
@@ -1495,10 +1497,10 @@ var x, y bigint
 var z bigint = x + y
 `, `package main
 
-import "github.com/goplus/gop/builtin/ng"
+import "github.com/qiniu/x/xgo/ng"
 
 var x, y ng.Bigint
-var z ng.Bigint = (ng.Bigint).Gop_Add(x, y)
+var z ng.Bigint = (ng.Bigint).XGo_Add(x, y)
 `)
 }
 
@@ -1508,7 +1510,7 @@ var x = 1r
 `, `package main
 
 import (
-	"github.com/goplus/gop/builtin/ng"
+	"github.com/qiniu/x/xgo/ng"
 	"math/big"
 )
 
@@ -1521,7 +1523,7 @@ func TestUint128Lit(t *testing.T) {
 var x uint128 = 1
 `, `package main
 
-import "github.com/goplus/gop/builtin/ng"
+import "github.com/qiniu/x/xgo/ng"
 
 var x ng.Uint128 = ng.Uint128_Init__0(1)
 `)
@@ -1532,7 +1534,7 @@ func TestInt128Lit(t *testing.T) {
 var x int128 = 1
 `, `package main
 
-import "github.com/goplus/gop/builtin/ng"
+import "github.com/qiniu/x/xgo/ng"
 
 var x ng.Int128 = ng.Int128_Init__0(1)
 `)
@@ -1544,7 +1546,7 @@ var x = 1/2r
 `, `package main
 
 import (
-	"github.com/goplus/gop/builtin/ng"
+	"github.com/qiniu/x/xgo/ng"
 	"math/big"
 )
 
@@ -1558,7 +1560,7 @@ var x = 3 + 1/2r
 `, `package main
 
 import (
-	"github.com/goplus/gop/builtin/ng"
+	"github.com/qiniu/x/xgo/ng"
 	"math/big"
 )
 
@@ -1575,13 +1577,13 @@ var z = 100 + y
 `, `package main
 
 import (
-	"github.com/goplus/gop/builtin/ng"
+	"github.com/qiniu/x/xgo/ng"
 	"math/big"
 )
 
 var x = ng.Bigrat_Init__2(big.NewRat(7, 2))
-var y = (ng.Bigrat).Gop_Add(x, ng.Bigrat_Init__0(100))
-var z = (ng.Bigrat).Gop_Add(ng.Bigrat_Init__0(100), y)
+var y = (ng.Bigrat).XGo_Add(x, ng.Bigrat_Init__0(100))
+var z = (ng.Bigrat).XGo_Add(ng.Bigrat_Init__0(100), y)
 `)
 }
 
@@ -1688,12 +1690,12 @@ var x bigint
 x += 3
 `, `package main
 
-import "github.com/goplus/gop/builtin/ng"
+import "github.com/qiniu/x/xgo/ng"
 
 var x ng.Bigint
 
 func main() {
-	x.Gop_AddAssign(ng.Bigint_Init__0(3))
+	x.XGo_AddAssign(ng.Bigint_Init__0(3))
 }
 `)
 }
@@ -1705,13 +1707,13 @@ x *= 2
 `, `package main
 
 import (
-	"github.com/goplus/gop/builtin/ng"
+	"github.com/qiniu/x/xgo/ng"
 	"math/big"
 )
 
 func main() {
 	x := ng.Bigint_Init__1(big.NewInt(3))
-	x.Gop_MulAssign(ng.Bigint_Init__0(2))
+	x.XGo_MulAssign(ng.Bigint_Init__0(2))
 }
 `)
 }
@@ -1723,13 +1725,13 @@ x *= 2r
 `, `package main
 
 import (
-	"github.com/goplus/gop/builtin/ng"
+	"github.com/qiniu/x/xgo/ng"
 	"math/big"
 )
 
 func main() {
 	x := ng.Bigint_Init__1(big.NewInt(3))
-	x.Gop_MulAssign(ng.Bigint_Init__1(big.NewInt(2)))
+	x.XGo_MulAssign(ng.Bigint_Init__1(big.NewInt(2)))
 }
 `)
 }
@@ -1737,16 +1739,16 @@ func main() {
 func TestCompositeLit(t *testing.T) {
 	gopClTest(t, `
 x := []float64{1, 3.4, 5}
-y := map[string]int{"Hello": 1, "Go+": 5}
+y := map[string]int{"Hello": 1, "XGo": 5}
 z := [...]int{1, 3, 5}
-a := {"Hello": 1, "Go+": 5.1}
+a := {"Hello": 1, "XGo": 5.1}
 `, `package main
 
 func main() {
 	x := []float64{1, 3.4, 5}
-	y := map[string]int{"Hello": 1, "Go+": 5}
+	y := map[string]int{"Hello": 1, "XGo": 5}
 	z := [...]int{1, 3, 5}
-	a := map[string]float64{"Hello": 1, "Go+": 5.1}
+	a := map[string]float64{"Hello": 1, "XGo": 5.1}
 }
 `)
 }
@@ -2014,14 +2016,14 @@ func main() {
 func TestDeferGo(t *testing.T) {
 	gopClTest(t, `
 go println("Hi")
-defer println("Go+")
+defer println("XGo")
 `, `package main
 
 import "fmt"
 
 func main() {
 	go fmt.Println("Hi")
-	defer fmt.Println("Go+")
+	defer fmt.Println("XGo")
 }
 `)
 }
@@ -2168,6 +2170,7 @@ type foo struct {
 }
 
 func (p *foo) Gop_Enum() fooIter {
+	return fooIter{}
 }
 
 for k, v <- new(foo) {
@@ -2186,12 +2189,13 @@ func (p fooIter) Next() (key string, val int, ok bool) {
 	return
 }
 func (p *foo) Gop_Enum() fooIter {
+	return fooIter{}
 }
 func main() {
-	for _gop_it := new(foo).Gop_Enum(); ; {
-		var _gop_ok bool
-		k, v, _gop_ok := _gop_it.Next()
-		if !_gop_ok {
+	for _xgo_it := new(foo).Gop_Enum(); ; {
+		var _xgo_ok bool
+		k, v, _xgo_ok := _xgo_it.Next()
+		if !_xgo_ok {
 			break
 		}
 		fmt.Println(k, v)
@@ -2219,9 +2223,9 @@ type foo struct {
 func (p *foo) Gop_Enum(c func(val string)) {
 }
 func main() {
-	fmt.Println(func() (_gop_ret []string) {
+	fmt.Println(func() (_xgo_ret []string) {
 		new(foo).Gop_Enum(func(v string) {
-			_gop_ret = append(_gop_ret, v)
+			_xgo_ret = append(_xgo_ret, v)
 		})
 		return
 	}())
@@ -2250,7 +2254,7 @@ type foo struct {
 }
 
 func newFoo() *foo {
-	return &foo{key: [3, 7], val: ["Hi", "Go+"]}
+	return &foo{key: [3, 7], val: ["Hi", "XGo"]}
 }
 
 func (p *foo) Gop_Enum() *fooIter {
@@ -2284,13 +2288,13 @@ func (p *foo) Gop_Enum() *fooIter {
 	return &fooIter{data: p}
 }
 func newFoo() *foo {
-	return &foo{key: []int{3, 7}, val: []string{"Hi", "Go+"}}
+	return &foo{key: []int{3, 7}, val: []string{"Hi", "XGo"}}
 }
 func main() {
-	for _gop_it := newFoo().Gop_Enum(); ; {
-		var _gop_ok bool
-		k, v, _gop_ok := _gop_it.Next()
-		if !_gop_ok {
+	for _xgo_it := newFoo().Gop_Enum(); ; {
+		var _xgo_ok bool
+		k, v, _xgo_ok := _xgo_it.Next()
+		if !_xgo_ok {
 			break
 		}
 		fmt.Println(k, v)
@@ -2334,10 +2338,10 @@ y := {x: i for i, x <- ["1", "3", "5", "7", "11"]}
 `, `package main
 
 func main() {
-	y := func() (_gop_ret map[string]int) {
-		_gop_ret = map[string]int{}
+	y := func() (_xgo_ret map[string]int) {
+		_xgo_ret = map[string]int{}
 		for i, x := range []string{"1", "3", "5", "7", "11"} {
-			_gop_ret[x] = i
+			_xgo_ret[x] = i
 		}
 		return
 	}()
@@ -2347,15 +2351,15 @@ func main() {
 
 func TestMapComprehensionCond(t *testing.T) {
 	gopClTest(t, `
-z := {v: k for k, v <- {"Hello": 1, "Hi": 3, "xsw": 5, "Go+": 7}, v > 3}
+z := {v: k for k, v <- {"Hello": 1, "Hi": 3, "xsw": 5, "XGo": 7}, v > 3}
 `, `package main
 
 func main() {
-	z := func() (_gop_ret map[int]string) {
-		_gop_ret = map[int]string{}
-		for k, v := range map[string]int{"Hello": 1, "Hi": 3, "xsw": 5, "Go+": 7} {
+	z := func() (_xgo_ret map[int]string) {
+		_xgo_ret = map[int]string{}
+		for k, v := range map[string]int{"Hello": 1, "Hi": 3, "xsw": 5, "XGo": 7} {
 			if v > 3 {
-				_gop_ret[v] = k
+				_xgo_ret[v] = k
 			}
 		}
 		return
@@ -2366,15 +2370,15 @@ func main() {
 
 func TestMapComprehensionCond2(t *testing.T) {
 	gopClTest(t, `
-z := {t: k for k, v <- {"Hello": 1, "Hi": 3, "xsw": 5, "Go+": 7}, t := v; t > 3}
+z := {t: k for k, v <- {"Hello": 1, "Hi": 3, "xsw": 5, "XGo": 7}, t := v; t > 3}
 `, `package main
 
 func main() {
-	z := func() (_gop_ret map[int]string) {
-		_gop_ret = map[int]string{}
-		for k, v := range map[string]int{"Hello": 1, "Hi": 3, "xsw": 5, "Go+": 7} {
+	z := func() (_xgo_ret map[int]string) {
+		_xgo_ret = map[int]string{}
+		for k, v := range map[string]int{"Hello": 1, "Hi": 3, "xsw": 5, "XGo": 7} {
 			if t := v; t > 3 {
-				_gop_ret[t] = k
+				_xgo_ret[t] = k
 			}
 		}
 		return
@@ -2389,7 +2393,7 @@ hasFive := {for x <- ["1", "3", "5", "7", "11"], x == "5"}
 `, `package main
 
 func main() {
-	hasFive := func() (_gop_ok bool) {
+	hasFive := func() (_xgo_ok bool) {
 		for _, x := range []string{"1", "3", "5", "7", "11"} {
 			if x == "5" {
 				return true
@@ -2407,7 +2411,7 @@ y := {i for i, x <- ["1", "3", "5", "7", "11"], x == "5"}
 `, `package main
 
 func main() {
-	y := func() (_gop_ret int) {
+	y := func() (_xgo_ret int) {
 		for i, x := range []string{"1", "3", "5", "7", "11"} {
 			if x == "5" {
 				return i
@@ -2425,7 +2429,7 @@ y, ok := {i for i, x <- ["1", "3", "5", "7", "11"], x == "5"}
 `, `package main
 
 func main() {
-	y, ok := func() (_gop_ret int, _gop_ok bool) {
+	y, ok := func() (_xgo_ret int, _xgo_ok bool) {
 		for i, x := range []string{"1", "3", "5", "7", "11"} {
 			if x == "5" {
 				return i, true
@@ -2445,7 +2449,7 @@ func foo() (int, bool) {
 `, `package main
 
 func foo() (int, bool) {
-	return func() (_gop_ret int, _gop_ok bool) {
+	return func() (_xgo_ret int, _xgo_ok bool) {
 		for i, x := range []string{"1", "3", "5", "7", "11"} {
 			if x == "5" {
 				return i, true
@@ -2465,9 +2469,9 @@ b := [x*x for x <- a]
 
 func main() {
 	a := []float64{1, 3.4, 5}
-	b := func() (_gop_ret []float64) {
+	b := func() (_xgo_ret []float64) {
 		for _, x := range a {
-			_gop_ret = append(_gop_ret, x*x)
+			_xgo_ret = append(_xgo_ret, x*x)
 		}
 		return
 	}()
@@ -2486,12 +2490,12 @@ import "fmt"
 
 func main() {
 	arr := []float64{1, 2, 3, 4.1, 5, 6}
-	x := func() (_gop_ret [][]float64) {
+	x := func() (_xgo_ret [][]float64) {
 		for _, b := range arr {
 			if b > 2 {
 				for _, a := range arr {
 					if a < b {
-						_gop_ret = append(_gop_ret, []float64{a, b})
+						_xgo_ret = append(_xgo_ret, []float64{a, b})
 					}
 				}
 			}
@@ -2509,7 +2513,7 @@ a := [1, 3, 5, 7, 9]
 b := a[:3]
 c := a[1:]
 d := a[1:2:3]
-e := "Hello, Go+"[7:]
+e := "Hello, XGo"[7:]
 `, `package main
 
 func main() {
@@ -2517,22 +2521,22 @@ func main() {
 	b := a[:3]
 	c := a[1:]
 	d := a[1:2:3]
-	e := "Hello, Go+"[7:]
+	e := "Hello, XGo"[7:]
 }
 `)
 }
 
 func TestIndexGetTwoValue(t *testing.T) {
 	gopClTest(t, `
-a := {"Hello": 1, "Hi": 3, "xsw": 5, "Go+": 7}
+a := {"Hello": 1, "Hi": 3, "xsw": 5, "XGo": 7}
 x, ok := a["Hi"]
-y := a["Go+"]
+y := a["XGo"]
 `, `package main
 
 func main() {
-	a := map[string]int{"Hello": 1, "Hi": 3, "xsw": 5, "Go+": 7}
+	a := map[string]int{"Hello": 1, "Hi": 3, "xsw": 5, "XGo": 7}
 	x, ok := a["Hi"]
-	y := a["Go+"]
+	y := a["XGo"]
 }
 `)
 }
@@ -2758,7 +2762,7 @@ func TestLocalImport(t *testing.T) {
 var a = spx.TestIntValue
 `, `package main
 
-import "github.com/goplus/gop/cl/internal/spx"
+import "github.com/goplus/xgo/cl/internal/spx"
 
 var a = spx.TestIntValue
 `)
@@ -2790,14 +2794,14 @@ func main() {
 
 func TestAnonymousImport(t *testing.T) {
 	gopClTest(t, `println("Hello")
-printf("Hello Go+\n")
+printf("Hello XGo\n")
 `, `package main
 
 import "fmt"
 
 func main() {
 	fmt.Println("Hello")
-	fmt.Printf("Hello Go+\n")
+	fmt.Printf("Hello XGo\n")
 }
 `)
 }
@@ -3336,7 +3340,7 @@ func TestFuncAsParam(t *testing.T) {
 	gopClTest(t, `import "fmt"
 
 func bar(foo func(string, ...interface{}) (int, error)) {
-	foo("Hello, %v!\n", "Go+")
+	foo("Hello, %v!\n", "XGo")
 }
 
 bar(fmt.Printf)
@@ -3345,7 +3349,7 @@ bar(fmt.Printf)
 import "fmt"
 
 func bar(foo func(string, ...interface{}) (int, error)) {
-	foo("Hello, %v!\n", "Go+")
+	foo("Hello, %v!\n", "XGo")
 }
 func main() {
 	bar(fmt.Printf)
@@ -3369,12 +3373,12 @@ func printf(format string, args ...interface{}) (n int, err error) {
 }
 
 func bar(foo func(string, ...interface{}) (int, error)) {
-	foo("Hello, %v!\n", "Go+")
+	foo("Hello, %v!\n", "XGo")
 }
 
 bar(printf)
 fmt.Println(foo("Hello, world???"))
-fmt.Println(printf("Hello, %v\n", "Go+"))
+fmt.Println(printf("Hello, %v\n", "XGo"))
 `, `package main
 
 import (
@@ -3390,12 +3394,12 @@ func printf(format string, args ...interface{}) (n int, err error) {
 	return
 }
 func bar(foo func(string, ...interface{}) (int, error)) {
-	foo("Hello, %v!\n", "Go+")
+	foo("Hello, %v!\n", "XGo")
 }
 func main() {
 	bar(printf)
 	fmt.Println(foo("Hello, world???"))
-	fmt.Println(printf("Hello, %v\n", "Go+"))
+	fmt.Println(printf("Hello, %v\n", "XGo"))
 }
 `)
 }
@@ -3520,7 +3524,7 @@ func TestImportGopPkg(t *testing.T) {
 	defer autogen.Unlock()
 
 	removeAutogenFiles()
-	gopClTest(t, `import "github.com/goplus/gop/cl/internal/gop-in-go/foo"
+	gopClTest(t, `import "github.com/goplus/xgo/cl/internal/gop-in-go/foo"
 
 rmap := foo.ReverseMap(map[string]int{"Hi": 1, "Hello": 2})
 println(rmap)
@@ -3528,7 +3532,7 @@ println(rmap)
 
 import (
 	"fmt"
-	"github.com/goplus/gop/cl/internal/gop-in-go/foo"
+	"github.com/goplus/xgo/cl/internal/gop-in-go/foo"
 )
 
 func main() {
@@ -3608,10 +3612,12 @@ func TestGoFuncInstr(t *testing.T) {
 //go:noinline
 //go:uintptrescapes
 func test(s string, p, q uintptr, rest ...uintptr) int {
+	return 0
 }`, `package main
 //go:noinline
 //go:uintptrescapes
 func test(s string, p uintptr, q uintptr, rest ...uintptr) int {
+	return 0
 }
 `)
 }
@@ -3844,24 +3850,24 @@ type Point struct {
 	x int
 	y int
 }
-//line /foo/bar.gop:7:1
+//line /foo/bar.xgo:7:1
 func (pt *Point) Test() {
-//line /foo/bar.gop:8:1
+//line /foo/bar.xgo:8:1
 	fmt.Println(pt.x, pt.y)
 }
-//line /foo/bar.gop:11:1
+//line /foo/bar.xgo:11:1
 // testPoint is test point
 func testPoint() {
-//line /foo/bar.gop:13:1
+//line /foo/bar.xgo:13:1
 	var pt Point
-//line /foo/bar.gop:14:1
+//line /foo/bar.xgo:14:1
 	pt.Test()
 }
-//line /foo/bar.gop:17
+//line /foo/bar.xgo:17
 func main() {
-//line /foo/bar.gop:17:1
+//line /foo/bar.xgo:17:1
 	fmt.Println("hello")
-//line /foo/bar.gop:18:1
+//line /foo/bar.xgo:18:1
 	testPoint()
 }
 `)
@@ -3898,24 +3904,24 @@ type Point struct {
 	x int
 	y int
 }
-//line ../bar.gop:7:1
+//line ../bar.xgo:7:1
 func (pt *Point) Test() {
-//line ../bar.gop:8:1
+//line ../bar.xgo:8:1
 	fmt.Println(pt.x, pt.y)
 }
-//line ../bar.gop:11:1
+//line ../bar.xgo:11:1
 // testPoint is test point
 func testPoint() {
-//line ../bar.gop:13:1
+//line ../bar.xgo:13:1
 	var pt Point
-//line ../bar.gop:14:1
+//line ../bar.xgo:14:1
 	pt.Test()
 }
-//line ../bar.gop:17
+//line ../bar.xgo:17
 func main() {
-//line ../bar.gop:17:1
+//line ../bar.xgo:17:1
 	fmt.Println("hello")
-//line ../bar.gop:18:1
+//line ../bar.xgo:18:1
 	testPoint()
 }
 `
@@ -3995,18 +4001,18 @@ println c
 import "fmt"
 // doc a line2
 var a int
-//line /foo/bar.gop:4
+//line /foo/bar.xgo:4
 func main() {
-//line /foo/bar.gop:4:1
+//line /foo/bar.xgo:4:1
 	fmt.Println(a)
-//line /foo/bar.gop:6:1
+//line /foo/bar.xgo:6:1
 	// doc b line6
 	var b int
-//line /foo/bar.gop:8:1
+//line /foo/bar.xgo:8:1
 	fmt.Println(b)
-//line /foo/bar.gop:10:1
+//line /foo/bar.xgo:10:1
 	var c int
-//line /foo/bar.gop:11:1
+//line /foo/bar.xgo:11:1
 	fmt.Println(c)
 }
 `)
@@ -4027,21 +4033,21 @@ func demo() {
 `, `package main
 
 import "fmt"
-//line /foo/bar.gop:2:1
+//line /foo/bar.xgo:2:1
 func demo() {
-//line /foo/bar.gop:3:1
+//line /foo/bar.xgo:3:1
 	// doc a line3
 	var a int
-//line /foo/bar.gop:5:1
+//line /foo/bar.xgo:5:1
 	fmt.Println(a)
-//line /foo/bar.gop:7:1
+//line /foo/bar.xgo:7:1
 	// doc b line7
 	var b int
-//line /foo/bar.gop:9:1
+//line /foo/bar.xgo:9:1
 	fmt.Println(b)
-//line /foo/bar.gop:11:1
+//line /foo/bar.xgo:11:1
 	var c int
-//line /foo/bar.gop:12:1
+//line /foo/bar.xgo:12:1
 	fmt.Println(c)
 }
 `)
@@ -4301,42 +4307,171 @@ func Bar() (int, error) {
 	return 100, nil
 }
 func main() {
-	func() (_gop_ret func()) {
-		var _gop_err error
-		_gop_ret, _gop_err = foo()
-		if _gop_err != nil {
-			_gop_err = errors.NewFrame(_gop_err, "foo", "/foo/bar.gop", 8, "main.main")
-			panic(_gop_err)
+	func() (_xgo_ret func()) {
+		var _xgo_err error
+		_xgo_ret, _xgo_err = foo()
+		if _xgo_err != nil {
+			_xgo_err = errors.NewFrame(_xgo_err, "foo", "/foo/bar.xgo", 8, "main.main")
+			panic(_xgo_err)
 		}
 		return
 	}()()
-	func() (_gop_ret func()) {
-		var _gop_err error
-		_gop_ret, _gop_err = foo(1)
-		if _gop_err != nil {
-			_gop_err = errors.NewFrame(_gop_err, "foo(1)", "/foo/bar.gop", 9, "main.main")
-			panic(_gop_err)
+	func() (_xgo_ret func()) {
+		var _xgo_err error
+		_xgo_ret, _xgo_err = foo(1)
+		if _xgo_err != nil {
+			_xgo_err = errors.NewFrame(_xgo_err, "foo(1)", "/foo/bar.xgo", 9, "main.main")
+			panic(_xgo_err)
 		}
 		return
 	}()()
-	fmt.Println(func() (_gop_ret func()) {
-		var _gop_err error
-		_gop_ret, _gop_err = foo()
-		if _gop_err != nil {
-			_gop_err = errors.NewFrame(_gop_err, "foo", "/foo/bar.gop", 10, "main.main")
-			panic(_gop_err)
+	fmt.Println(func() (_xgo_ret func()) {
+		var _xgo_err error
+		_xgo_ret, _xgo_err = foo()
+		if _xgo_err != nil {
+			_xgo_err = errors.NewFrame(_xgo_err, "foo", "/foo/bar.xgo", 10, "main.main")
+			panic(_xgo_err)
 		}
 		return
 	}())
-	fmt.Println(func() (_gop_ret int) {
-		var _gop_err error
-		_gop_ret, _gop_err = Bar()
-		if _gop_err != nil {
-			_gop_err = errors.NewFrame(_gop_err, "bar", "/foo/bar.gop", 11, "main.main")
-			panic(_gop_err)
+	fmt.Println(func() (_xgo_ret int) {
+		var _xgo_err error
+		_xgo_ret, _xgo_err = Bar()
+		if _xgo_err != nil {
+			_xgo_err = errors.NewFrame(_xgo_err, "bar", "/foo/bar.xgo", 11, "main.main")
+			panic(_xgo_err)
 		}
 		return
 	}())
 }
 `)
 }
+
+func TestCommentFunc(t *testing.T) {
+	gopClTestEx(t, gblConfLine, "main", `
+import (
+	"strconv"
+)
+
+func add(x, y string) (int, error) {
+	return strconv.atoi(x)? + strconv.atoi(y)?, nil
+}
+
+func addSafe(x, y string) int {
+	return strconv.atoi(x)?:0 + strconv.atoi(y)?:0
+}
+
+echo add("100", "23")!
+
+sum, err := add("10", "abc")
+echo sum, err
+
+echo addSafe("10", "abc")
+`, `package main
+
+import (
+	"fmt"
+	"github.com/qiniu/x/errors"
+	"strconv"
+)
+//line /foo/bar.xgo:6:1
+func add(x string, y string) (int, error) {
+//line /foo/bar.xgo:7:1
+	var _autoGo_1 int
+//line /foo/bar.xgo:7:1
+	{
+//line /foo/bar.xgo:7:1
+		var _xgo_err error
+//line /foo/bar.xgo:7:1
+		_autoGo_1, _xgo_err = strconv.Atoi(x)
+//line /foo/bar.xgo:7:1
+		if _xgo_err != nil {
+//line /foo/bar.xgo:7:1
+			_xgo_err = errors.NewFrame(_xgo_err, "strconv.atoi(x)", "/foo/bar.xgo", 7, "main.add")
+//line /foo/bar.xgo:7:1
+			return 0, _xgo_err
+		}
+//line /foo/bar.xgo:7:1
+		goto _autoGo_2
+	_autoGo_2:
+//line /foo/bar.xgo:7:1
+	}
+//line /foo/bar.xgo:7:1
+	var _autoGo_3 int
+//line /foo/bar.xgo:7:1
+	{
+//line /foo/bar.xgo:7:1
+		var _xgo_err error
+//line /foo/bar.xgo:7:1
+		_autoGo_3, _xgo_err = strconv.Atoi(y)
+//line /foo/bar.xgo:7:1
+		if _xgo_err != nil {
+//line /foo/bar.xgo:7:1
+			_xgo_err = errors.NewFrame(_xgo_err, "strconv.atoi(y)", "/foo/bar.xgo", 7, "main.add")
+//line /foo/bar.xgo:7:1
+			return 0, _xgo_err
+		}
+//line /foo/bar.xgo:7:1
+		goto _autoGo_4
+	_autoGo_4:
+//line /foo/bar.xgo:7:1
+	}
+//line /foo/bar.xgo:7:1
+	return _autoGo_1 + _autoGo_3, nil
+}
+//line /foo/bar.xgo:10:1
+func addSafe(x string, y string) int {
+//line /foo/bar.xgo:11:1
+	return func() (_xgo_ret int) {
+//line /foo/bar.xgo:11:1
+		var _xgo_err error
+//line /foo/bar.xgo:11:1
+		_xgo_ret, _xgo_err = strconv.Atoi(x)
+//line /foo/bar.xgo:11:1
+		if _xgo_err != nil {
+//line /foo/bar.xgo:11:1
+			return 0
+		}
+//line /foo/bar.xgo:11:1
+		return
+	}() + func() (_xgo_ret int) {
+//line /foo/bar.xgo:11:1
+		var _xgo_err error
+//line /foo/bar.xgo:11:1
+		_xgo_ret, _xgo_err = strconv.Atoi(y)
+//line /foo/bar.xgo:11:1
+		if _xgo_err != nil {
+//line /foo/bar.xgo:11:1
+			return 0
+		}
+//line /foo/bar.xgo:11:1
+		return
+	}()
+}
+//line /foo/bar.xgo:14
+func main() {
+//line /foo/bar.xgo:14:1
+	fmt.Println(func() (_xgo_ret int) {
+//line /foo/bar.xgo:14:1
+		var _xgo_err error
+//line /foo/bar.xgo:14:1
+		_xgo_ret, _xgo_err = add("100", "23")
+//line /foo/bar.xgo:14:1
+		if _xgo_err != nil {
+//line /foo/bar.xgo:14:1
+			_xgo_err = errors.NewFrame(_xgo_err, "add(\"100\", \"23\")", "/foo/bar.xgo", 14, "main.main")
+//line /foo/bar.xgo:14:1
+			panic(_xgo_err)
+		}
+//line /foo/bar.xgo:14:1
+		return
+	}())
+//line /foo/bar.xgo:16:1
+	sum, err := add("10", "abc")
+//line /foo/bar.xgo:17:1
+	fmt.Println(sum, err)
+//line /foo/bar.xgo:19:1
+	fmt.Println(addSafe("10", "abc"))
+}
+`)
+}
