@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2022 The GoPlus Authors (goplus.org). All rights reserved.
+ * Copyright (c) 2022 The XGo Authors (xgo.dev). All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,9 +19,13 @@ package cl_test
 import (
 	"testing"
 
-	"github.com/goplus/gop/cl/cltest"
+	"github.com/goplus/xgo/cl/cltest"
 )
 
+func TestTestspx(t *testing.T) {
+	cltest.SpxFromDir(t, "", "./_testspx")
+}
+
 func TestTestgop(t *testing.T) {
 	cltest.FromDir(t, "", "./_testgop")
 }
