@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2021 The GoPlus Authors (goplus.org). All rights reserved.
+ * Copyright (c) 2021 The XGo Authors (xgo.dev). All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,7 +20,7 @@ import (
 	"log"
 	"os"
 
-	"github.com/goplus/gop/cmd/internal/base"
+	"github.com/goplus/xgo/cmd/internal/base"
 )
 
 var Cmd = &base.Command{
@@ -28,9 +28,9 @@ var Cmd = &base.Command{
 	Short:     "Module maintenance",
 
 	Commands: []*base.Command{
-		cmdInit,
-		cmdDownload,
-		cmdTidy,
+		CmdInit,
+		CmdDownload,
+		CmdTidy,
 	},
 }
 
