@@ -5,6 +5,6 @@ import (
 	"reflect"
 )
 
-func Gopx_Col[T any](name string) {
+func XGox_Col[T any](name string) {
 	fmt.Printf("%v: %s\n", reflect.TypeOf((*T)(nil)).Elem(), name)
 }
