@@ -2,7 +2,7 @@
 // +build !windows
 
 /*
- * Copyright (c) 2021 The GoPlus Authors (goplus.org). All rights reserved.
+ * Copyright (c) 2021 The XGo Authors (xgo.dev). All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,6 +19,6 @@
 
 package env
 
-func isGopCmd(fname string) bool {
-	return fname == "gop"
+func isXgoCmd(fname string) bool {
+	return fname == "xgo" || fname == "gop"
 }
