@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2021 The GoPlus Authors (goplus.org). All rights reserved.
+ * Copyright (c) 2021 The XGo Authors (xgo.dev). All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,10 +16,13 @@
 
 package env
 
+import "strings"
+
 const (
 	envHOME = "USERPROFILE"
 )
 
-func isGopCmd(fname string) bool {
-	return fname == "gop.exe" || fname == "gop"
+func isXgoCmd(fname string) bool {
+	fname = strings.TrimSuffix(fname, ".exe")
+	return fname == "xgo" || fname == "gop"
 }
