@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2021 The GoPlus Authors (goplus.org). All rights reserved.
+ * Copyright (c) 2021 The XGo Authors (xgo.dev). All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -29,8 +29,8 @@ import (
 	"unicode"
 	"unicode/utf8"
 
-	"github.com/goplus/gop/ast"
-	"github.com/goplus/gop/token"
+	"github.com/goplus/xgo/ast"
+	"github.com/goplus/xgo/token"
 )
 
 const (
@@ -395,6 +395,10 @@ func (p *printer) parameters(fields *ast.FieldList) {
 			}
 			// parameter type
 			p.expr(stripParensAlways(par.Type))
+			// optional parameter marker
+			if par.Optional.IsValid() {
+				p.print(token.QUESTION)
+			}
 			prevLine = parLineEnd
 		}
 		// if the closing ")" is on a separate line from the last parameter,
@@ -943,6 +947,18 @@ func (p *printer) expr1(expr ast.Expr, prec1, depth int) {
 		} else {
 			p.exprList(x.Lparen, x.Args, depth, commaTerm, x.Rparen, false)
 		}
+		if len(x.Kwargs) > 0 {
+			if len(x.Args) > 0 {
+				p.print(token.COMMA, blank)
+			}
+			for i, arg := range x.Kwargs {
+				if i > 0 {
+					p.print(token.COMMA, blank)
+				}
+				p.print(arg.Name, blank, token.ASSIGN, blank)
+				p.expr0(arg.Value, depth)
+			}
+		}
 		if x.NoParenEnd == token.NoPos {
 			p.print(x.Rparen, token.RPAREN)
 		}
@@ -1033,6 +1049,9 @@ func (p *printer) expr1(expr ast.Expr, prec1, depth int) {
 		}
 		p.print(blank)
 		p.expr(x.Value)
+
+	case *ast.TupleType:
+		p.parameters(x.Fields)
 		/*	case *ast.TernaryExpr:
 			p.expr1(x.X, token.HighestPrec, 1)
 			p.expr0(x.Cond, 1)
@@ -1050,6 +1069,15 @@ func (p *printer) expr1(expr ast.Expr, prec1, depth int) {
 		}
 		p.print(mode, x.Rbrack, token.RBRACK, mode)
 
+	case *ast.TupleLit:
+		p.print(token.LPAREN)
+		p.exprList(x.Lparen, x.Elts, depth+1, commaTerm, x.Rparen, false)
+		mode := noExtraLinebreak
+		if len(x.Elts) > 0 {
+			mode |= noExtraBlank
+		}
+		p.print(mode, x.Rparen, token.RPAREN, mode)
+
 	case *ast.ComprehensionExpr:
 		switch x.Tok {
 		case token.LBRACK: // [...]
@@ -1370,6 +1398,12 @@ func (p *printer) indentList(list []ast.Expr) bool {
 func (p *printer) stmt(stmt ast.Stmt, nextIsRBrace bool) {
 	p.print(stmt.Pos())
 
+	if p.commentedStmts != nil {
+		if comments, ok := p.commentedStmts[stmt]; ok {
+			p.setComment(comments)
+		}
+	}
+
 	switch s := stmt.(type) {
 	case *ast.BadStmt:
 		p.print("BadStmt")
