@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2025 The GoPlus Authors (goplus.org). All rights reserved.
+ * Copyright (c) 2025 The XGo Authors (xgo.dev). All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@ package time
 import (
 	"time"
 
-	"github.com/goplus/gop/tpl/variant"
+	"github.com/goplus/xgo/tpl/variant"
 )
 
 // -----------------------------------------------------------------------------
